from AutoRPE.UtilsRPE.SourceManager import load_vault
from os.path import isfile


def get_command_line_arguments():
    import argparse
    parser = argparse.ArgumentParser()
    parser.add_argument("-v", "--vault", default=None,
                        help="Path to the vault.")
    parser.add_argument("-o", "--output-namelist", default="namelist_precisions",
                        help="Filename for the output namelist.")

    args = parser.parse_args()

    if args.vault is None:
        parser.error("Argument -v/--vault required!")

    if not isfile(args.vault) is None:
        parser.error("Argument -v/--vault %s is not a file." % args.vault)

    return args


def set_precision_to(value, _vault):
    for variable in _vault.variables:
        if variable.mutable:
            variable.precision = value


if __name__ == "__main__":

    args = get_command_line_arguments()
    vault_path = args.vault
    output_filename = args.output_namelist

    vault = load_vault(vault_path)

    if not vault:
        print("Not able to load %s !\nUnable to create namelist!" % vault_path)
        exit(1)

    variables = sorted([var for var in vault.variables if var.mutable], key=lambda x: x.id)

    set_precision_to(52, vault)

    vault.generate_namelist_precisions(filename=output_filename, exclude_double_precision=False)
